import React from 'react'
import PropTypes from 'prop-types'
import { Helmet } from 'react-helmet'

import SiteMetadata from '../query/siteMetadata'

function SEO({
  description,
  language,
  metaTags,
  title,
  imageRelativePath,
  pathname,
}) {
  const {
    description: site_description,
    name: site_name,
    siteUrl,
  } = SiteMetadata()

  const metaDescription = description || site_description
  const metaTitle = title ? `${title} | ${site_name}` : site_name
  const siteImageUrl = siteUrl + imageRelativePath
  const pageUrl = siteUrl + pathname

  return (
    <Helmet
      htmlAttributes={{
        language,
      }}
      title={metaTitle}
      link={[{ rel: 'canonical', href: pageUrl }]}
      meta={[
        {
          name: 'description',
          content: metaDescription,
        },
        {
          property: 'og:title',
          content: metaTitle,
        },
        {
          property: 'og:description',
          content: metaDescription,
        },
        {
          property: 'og:type',
          content: 'website',
        },
        {
          property: 'og:image',
          content: siteImageUrl,
        },
        {
          property: 'og:url',
          content: pageUrl,
        },
        {
          name: 'twitter:card',
          content: 'summary',
        },
        {
          name: 'twitter:title',
          content: metaTitle,
        },
        {
          name: 'twitter:description',
          content: metaDescription,
        },
        {
          name: 'twitter:image',
          content: siteImageUrl,
        },
      ].concat(metaTags)}
    />
  )
}

SEO.defaultProps = {
  language: 'sv',
  metaTags: [],
  pathname: '',
}

SEO.propTypes = {
  description: PropTypes.string,
  imageRelativePath: PropTypes.string.isRequired,
  language: PropTypes.string,
  metaTags: PropTypes.arrayOf(PropTypes.object),
  pathname: PropTypes.string,
  title: PropTypes.string,
}

export default SEO
